@@ -2,6 +2,7 @@
 Unimatrix framework.
 """
 import os
+import tempfile
 
 
 # Specifies the default database connection. If
@@ -24,6 +25,6 @@ SECDIR = os.getenv('APP_SECDIR',
 # TLS is used with network connections, if possible.
 TLS_ENFORCE = not os.getenv('DISABLE_TLS_ENFORCE') == '1'
 
-TMPDIR = os.getenv('TMPDIR', '/tmp')
+TMPDIR = tempfile.gettempdir()
 
 VARDIR = os.getenv('APP_VARDIR', '/var/lib/app')
